# AUTO AIML
This module takes input csv/excel file and regression/classification flag and it processes the file and create the best model.


## Installation
```pip install auto-aiml```

## How to use it?
Open terminal and the give regression flag yes  and No for classification then csv/ excel flag Y/N and the file location and that it you are done, wait the process to complete and you can get best model .

## License

© 2020 Yashwanth Agastya

This repository is licensed under the MIT license. See LICENSE for details.